package App::setop;

our $VERSION = '0.10'; # VERSION

1;
# ABSTRACT: Set operations (union, intersection, difference, symmetric diff) on lines of files

__END__

=pod

=encoding UTF-8

=head1 NAME

App::setop - Set operations (union, intersection, difference, symmetric diff) on lines of files

=head1 VERSION

This document describes version 0.10 of App::setop (from Perl distribution App-setop), released on 2015-11-13.

=head1 SYNOPSIS

See the command-line script L<setop>.

=head1 SEE ALSO

L<Array::Utils>

L<Set::Scalar>

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/App-setop>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-App-setop>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-setop>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2015 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
